# Проект по MLOps

<a target="_blank" href="https://cookiecutter-data-science.drivendata.org/">
    <img src="https://img.shields.io/badge/CCDS-Project%20template-328F97?logo=cookiecutter" />
</a>

Проект по MLOps от VK Education x МГТУ им. Н. Э. Баумана (Весна 2025)

## Установка пакета проекта

```bash
pip install mlops-project
```

## Команды для поднятия проекта в registry

```bash
pip install build twine # Для сборки (build) и публикации проекта в PyPI (twine)
python -m build # (Создает дистрибутив проекта в папке ./dist будет исходный код и бинарный файл) 
twine upload dist/* # Выгрузка проекта (С использоанием API ключа PyPI)
```

## Структура проекта

```
├── LICENSE            <- Лицензия с открытым исходным кодом, если она выбрана
├── Makefile           <- Makefile с удобными командами, такими как `make data` или `make train`
├── README.md          <- Основной README для разработчиков, использующих этот проект.
├── data
│   ├── external       <- Данные из сторонних источников.
│   ├── interim        <- Промежуточные данные, которые были преобразованы.
│   ├── processed      <- Окончательные, канонические наборы данных для моделирования.
│   └── raw            <- Исходные, неизменяемые данные.
│
├── docs               <- Стандартный проект mkdocs; подробности на www.mkdocs.org
│
├── models             <- Обученные и сериализованные модели, предсказания моделей или сводки моделей
│
├── notebooks          <- Jupyter notebooks. Соглашение по именованию: число (для порядка),
│                         инициалы создателя и краткое описание через `-`, например,
│                         `1.0-jqp-initial-data-exploration`.
│
├── pyproject.toml     <- Файл конфигурации проекта с метаданными пакета для 
│                         ml_project и настройками для инструментов, таких как black
│
├── references         <- Словари данных, руководства и другие справочные материалы.
│
├── reports            <- Сгенерированные аналитические отчеты в форматах HTML, PDF, LaTeX и т.д.
│   └── figures        <- Сгенерированные графики и изображения для использования в отчетах
│
├── requirements.txt   <- Файл зависимостей для воссоздания аналитической среды, например,
│                         созданный командой `pip freeze > requirements.txt`
│
├── setup.cfg          <- Файл конфигурации для flake8
│
└── ml_project   <- Исходный код для использования в этом проекте.
    │
    ├── __init__.py             <- Делает ml_project Python-модулем
    │
    ├── config.py               <- Хранит полезные переменные и конфигурацию
    │
    ├── dataset.py              <- Скрипты для загрузки или генерации данных
    │
    ├── features.py             <- Код для создания признаков для моделирования
    │
    ├── modeling                
    │   ├── __init__.py 
    │   ├── predict.py          <- Код для выполнения предсказаний с использованием обученных моделей          
    │   └── train.py            <- Код для обучения моделей
    │
    └── plots.py                <- Код для создания визуализаций
```

--------

